Crate enki

Crate enki 

Enki

Pure Rust heterogeneous GPU compute platform with Just-In-Time (JIT) compilation.

Enki enables writing high-performance compute and graphics algorithms using standard, idiomatic Rust (structs, traits, pattern matching, iters, atomics, enums and payloads, macros, and crates.io dependencies) and executes them across GPU and CPU hardware with zero-cost abstractions.

Re-exports

pub use enki_api::context::Enki;
pub use enki_api::context::EnkiBuilder;
pub use enki_api::context::Flow;
pub use enki_api::context::GpuInstant;
pub use enki_api::context::active_engine;
pub use enki_api::context::active_enki;
pub use enki_api::context::set_active_enki;
pub use enki_api::space::IntoTile;
pub use enki_api::space::Space;
pub use enki_api::space::TileConfig;
pub use enki_api::resources::GpuAtomic;
pub use enki_api::resources::GpuAtomicTarget;
pub use enki_api::resources::GpuAtomicVec;
pub use enki_api::resources::GpuParam;
pub use enki_api::resources::GpuTileMem;
pub use enki_api::resources::GpuVec;
pub use enki_api::resources::Slice;
pub use enki_api::resources::SliceMut;
pub use enki_api::type_safety::*;

Modules

enki_api
prelude
Convenient re-exports of common Enki types and traits.

Macros

gpu_vec
Creates a GpuVec containing the provided arguments.

Structs

NamParamMeta
NamSignatureContract

Enums

ExpectedParamKind

Attribute Macros

nam