Module instance

Module instance 

Structs

Enki
The central handle to the Enki heterogeneous GPU runtime.
EnkiBuilder
Builder for configuring engine settings before runtime initialization.

Functions

active_engine
Retrieves a clone of the underlying Vulkan compute engine (EnkiEngine).
active_enki
Retrieves a clone of the globally active Enki context.
set_active_enki
Sets the global active Enki context instance.