pub fn active_engine() -> Arc<EnkiEngine> ⓘExpand description
Retrieves a clone of the underlying Vulkan compute engine (EnkiEngine).
pub fn active_engine() -> Arc<EnkiEngine> ⓘRetrieves a clone of the underlying Vulkan compute engine (EnkiEngine).