pub struct EnkiBuilder { /* private fields */ }Expand description
Builder for configuring engine settings before runtime initialization.
Implementations
Sourceimpl EnkiBuilder
impl EnkiBuilder
pub fn new() -> Self
Sourcepub fn app_name(self, name: impl Into<String>) -> Self
pub fn app_name(self, name: impl Into<String>) -> Self
Sets the application name reported to the Vulkan driver.
Sourcepub fn param_arena_size(self, size_bytes: u64) -> Self
pub fn param_arena_size(self, size_bytes: u64) -> Self
Sets the maximum capacity in bytes allocated for uniform parameter uploads (ParamArena).
Sourcepub fn init(self) -> Arc<Enki> ⓘ
pub fn init(self) -> Arc<Enki> ⓘ
Finalizes configuration and initializes a headless GPU context.
Sourcepub fn init_windowed<W>(
self,
window: Arc<W>,
width: u32,
height: u32,
) -> Arc<Enki> ⓘ
pub fn init_windowed<W>( self, window: Arc<W>, width: u32, height: u32, ) -> Arc<Enki> ⓘ
Finalizes configuration and initializes a windowed presentation GPU context.
Sourcepub fn max_timestamp_queries(self, count: u32) -> Self
pub fn max_timestamp_queries(self, count: u32) -> Self
Sets the maximum number of hardware timestamp profiling queries per flow.